@@ -1,3 +1,4 @@
+import time
 import simplejson
 import pkg_resources
 
@@ -11,10 +12,10 @@ class TurboFlot(Widget):
         A TurboGears Flot Widget.
     """
     template = """
-      <div xmlns:py="http://purl.org/kid/ns#" id="turboflot" 
+      <div xmlns:py="http://purl.org/kid/ns#" id="turboflot${id}" 
            style="width:${width};height:${height};">
         <script>
-          $.plot($("#turboflot"), ${data}, ${options});
+          $.plot($("#turboflot${id}"), ${data}, ${options});
         </script>
       </div>
     """
@@ -30,6 +31,7 @@ class TurboFlot(Widget):
                   JSLink("turboflot", "jquery.flot.js")]
 
     def __init__(self, data, options={}, height="300px", width="600px"):
+        self.id = str(time.time()).split('.')[0]
         self.data = simplejson.dumps(data)
         self.options = simplejson.dumps(options)
         self.height = height
